@@ -1,27 +1,28 @@
-import asyncio
 import aiohttp
-from .bingresponse import BingResponse
+from searchresponse import SearchResponse
 
 class Search:
     """The searching part of asyncbing"""
-
-    def __init__(self, auth: str, session: aiohttp.ClientSession=None):
+    async def __aenter__(self, auth: str, *, session: aiohttp.ClientSession=None):
+        """Takes a `auth` token, as well as an optional aiohttp session.
+        example:
+        ``
+        async with asyncbing.Search('AUTHTOKEN') as searching:
+            await searching.fetch...
+        ``"""
         self.headers = {'Ocp-Apim-Subscription-Key': auth}
         self.bing = 'https://api.bing.microsoft.com/v7.0/search'
         if not session:
-            self.session = asyncio.run(self.session_setup())
+            async with aiohttp.ClientSession() as session:
+                self.session = session
         else:
             self.session = session
 
-    async def session_setup(self) -> aiohttp.ClientSession:
-        async with aiohttp.ClientSession() as session:
-            return session
-
-    async def fetch(self, search: str) -> BingResponse:
+    async def fetch(self, search: str) -> SearchResponse:
         """|coro|
         Searches with the bing api for the search string provided, with the global market set."""
         async with self.session.get(self.bing, headers=self.headers, params={'q': search}) as resp:
-            return BingResponse((await resp.json()))
+            return SearchResponse((await resp.json()))
 
     # "alias"
     async def search(self, *args, **kwargs) -> fetch:
